@@ -6,7 +6,6 @@ use warnings;
 use base qw(RDF::AllegroGraph::Repository);
 
 use Data::Dumper;
-use feature "switch";
 
 use JSON;
 use URI::Escape qw/uri_escape_utf8/;
@@ -249,24 +248,23 @@ sub _put_post_stmts {
 	} else {                                                                # scalar => N3
 	    $n3 .= $item;
 	}
-    }
+    } # foreach
 
     my $ua = $self->{CATALOG}->{SERVER}->{ua};                                  # local handle
 
     if (@stmts) {                                                               # if we have something to say to the server
-	given ($method) {
-	    when ('POST') {
+	if ($method eq 'POST') {
 		my $resp  = $ua->post ($self->{path} . '/statements',
 				       'Content-Type' => 'application/json', 'Content' => encode_json (\@stmts) );
 		die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
 	    }
-	    when ('PUT') {
+	elsif ($method eq 'PUT') {
 		my $requ = HTTP::Request->new (PUT => $self->{path} . '/statements',
 					       [ 'Content-Type' => 'application/json' ], encode_json (\@stmts));
 		my $resp = $ua->request ($requ);
 		die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
 	    }
-	    when ('DELETE') {                                                     # DELETE
+	elsif ($method eq 'DELETE') {                                                     # DELETE
 		# first bulk delete facts, i.e. where there are no wildcards
 		my @facts      = grep { defined $_->[0]   &&   defined $_->[1] &&   defined $_->[2] } @stmts;
 		my $requ = HTTP::Request->new (POST => $self->{path} . '/statements/delete',
@@ -282,9 +280,8 @@ sub _put_post_stmts {
 		    die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
 		}
 	    }
-	    default { die "You should never end here: Unhandled '$method'"; }
-	}
-    }
+	else { die "You should never end here: Unhandled '$method'"; }
+    } # if stmts
     if ($n3) {                                                                  # if we have something to say to the server
 	my $requ = HTTP::Request->new ($method => $self->{path} . '/statements', [ 'Content-Type' => 'text/plain' ], $n3);
 	my $resp = $ua->request ($requ);
@@ -294,23 +291,21 @@ sub _put_post_stmts {
 	use LWP::Simple;
 	my $content = get ($file) or die "Could not open URL '$file'";
 	my $mime;                                                               # lets guess the mime type
-	given ($file) {                                                         # magic does not normally cope well with RDF/N3, so do it by extension
-	    when (/\.n3$/)  { $mime = 'text/plain'; }                           # well, not really, since its text/n3
-	    when (/\.nt$/)  { $mime = 'text/plain'; }
-	    when (/\.xml$/) { $mime = 'application/rdf+xml'; }
-	    when (/\.rdf$/) { $mime = 'application/rdf+xml'; }
-	    default { die; }
-	}
+	                                                       # magic does not normally cope well with RDF/N3, so do it by extension
+	if ($file =~ m/\.n3$/)  { $mime = 'text/plain'; }                           # well, not really, since its text/n3
+	elsif ($file =~ m/\.nt$/)  { $mime = 'text/plain'; }
+	elsif ($file =~ m/\.xml$/) { $mime = 'application/rdf+xml'; }
+	elsif ($file =~ m/\.rdf$/) { $mime = 'application/rdf+xml'; }
+	else { die; }
 
 	my $requ = HTTP::Request->new ($method => $self->{path} . '/statements', [ 'Content-Type' => $mime ], $content);
 	my $resp = $ua->request ($requ);
 	die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
 
 	$method = 'POST';                                                        # whatever the first was, the others must add to it!
-    }
+    } # for
 
-
-}
+} # _put_post_stmts
 
 sub _to_uri {
     my $path    = shift;
@@ -433,13 +428,11 @@ sub _query {
     die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
 
     my $json = from_json ($resp->content);
-    given ($options{RETURN}) {
-	when ('TUPLE_LIST') {
+    if ($options{RETURN} eq 'TUPLE_LIST') {
 	    return $NAMED ? ($json) : @{ $json->{values} };
 	}
-	default { die };
-    }
-}
+    else { die };
+ } # _query
 
 =pod
 
@@ -888,13 +881,13 @@ sub indices {
 	} else {                                                                  # not sure what this is => ignorance is bliss
 	    warn "not sure what to do with '$sidx', ignoring ...";
 	}
-    }
+    } # foreach
     # now collect the state of affairs from the server
     my $url  = new URI ($self->{path} . '/indices');
     my $resp = $self->{CATALOG}->{SERVER}->{ua}->request (GET $url);
     die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
     return @{ from_json ($resp->content) };
-}
+} # indices
 
 
 =pod
@@ -923,19 +916,18 @@ sub _mode {
 	    my $resp = $ua->request ($requ);
 	    die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
 	}
-    }
+    } # if
     my $resp = $ua->get ($path);
     die "protocol error: ".$resp->status_line.' ('.$resp->content.')' unless $resp->is_success;
     return $resp->content eq 'true';
-}
+} # _mode
 
 sub bulk_loading_mode {
     my $self = shift;
     my $val  = shift;
 
     return _mode ($self->{CATALOG}->{SERVER}->{ua}, $self->{path} . '/bulkMode', $val);
-
-}
+} # bulk_loading_mode
 
 =pod
 
@@ -978,7 +970,7 @@ sub duplicate_suppression_mode {
 
 =cut
 
-our $VERSION  = '0.07';
+our $VERSION  = '0.08';
 
 1;
 
